==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/client/content/logistics/packagePort/postbox/PostboxRenderer.java <==
package com.zurrtum.create.client.content.logistics.packagePort.postbox;

import com.zurrtum.create.catnip.animation.LerpedFloat;
import com.zurrtum.create.client.AllPartialModels;
import com.zurrtum.create.client.catnip.render.CachedBuffers;
import com.zurrtum.create.client.catnip.render.SuperByteBuffer;
import com.zurrtum.create.client.foundation.blockEntity.renderer.SmartBlockEntityRenderer;
import com.zurrtum.create.client.foundation.blockEntity.renderer.SmartBlockEntityRenderer.NameplateRenderState;
import com.zurrtum.create.content.logistics.packagePort.postbox.PostboxBlock;
import com.zurrtum.create.content.logistics.packagePort.postbox.PostboxBlockEntity;
import net.minecraft.class_11659;
import net.minecraft.class_11683;
import net.minecraft.class_11954;
import net.minecraft.class_12075;
import net.minecraft.class_1921;
import net.minecraft.class_243;
import net.minecraft.class_2561;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4608;
import net.minecraft.class_5614;
import net.minecraft.class_827;
import org.jetbrains.annotations.Nullable;

public class PostboxRenderer implements class_827<PostboxBlockEntity, PostboxRenderer.PostboxRenderState> {
    public PostboxRenderer(class_5614.class_5615 context) {
    }

    @Override
    public PostboxRenderState method_74335() {
        return new PostboxRenderState();
    }

    @Override
    public void updateRenderState(
        PostboxBlockEntity be,
        PostboxRenderState state,
        float tickProgress,
        class_243 cameraPos,
        @Nullable class_11683.class_11792 crumblingOverlay
    ) {
        class_11954.method_74399(be, state, crumblingOverlay);
        state.layer = class_1921.method_23581();
        state.flag = CachedBuffers.partial(AllPartialModels.POSTBOX_FLAG, state.field_62674);
        state.angle = class_3532.field_29847 * (180 - state.field_62674.method_11654(PostboxBlock.field_11177).method_10144());
        LerpedFloat flag = be.flag;
        float value = flag.getValue(tickProgress);
        float progress = (float) (Math.pow(Math.min(value * 5, 1), 2));
        if (flag.getChaseTarget() > 0 && !flag.settled() && progress == 1) {
            float wiggleProgress = (value - .2f) / .8f;
            progress += (float) ((Math.sin(wiggleProgress * (2 * class_3532.field_29844) * 4) / 8f) / Math.max(1, 8f * wiggleProgress));
        }
        state.xRot = class_3532.field_29847 * (-progress * 90);
        String filter = be.addressFilter;
        if (filter != null && !filter.isBlank()) {
            state.name = SmartBlockEntityRenderer.getNameplateRenderState(
                be,
                state.field_62673,
                cameraPos,
                class_2561.method_43470(filter),
                1,
                state.field_62676
            );
        }
    }

    @Override
    public void render(PostboxRenderState state, class_4587 matrices, class_11659 queue, class_12075 cameraState) {
        queue.method_73483(matrices, state.layer, state);
        if (state.name != null) {
            state.name.render(matrices, queue, cameraState);
        }
    }

    public static class PostboxRenderState extends class_11954 implements class_11659.class_11660 {
        public class_1921 layer;
        public SuperByteBuffer flag;
        public float angle;
        public float xRot;
        public NameplateRenderState name;

        @Override
        public void render(class_4587.class_4665 matricesEntry, class_4588 vertexConsumer) {
            flag.light(field_62676).overlay(class_4608.field_21444).rotateYCentered(angle).translate(0, 0.625f, 0.125f).rotateX(xRot)
                .translate(0, -0.625f, -0.125f).renderInto(matricesEntry, vertexConsumer);
        }
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/client/content/logistics/packagePort/postbox/PostboxRenderer.java <==
package com.zurrtum.create.client.content.logistics.packagePort.postbox;

import com.zurrtum.create.catnip.animation.LerpedFloat;
import com.zurrtum.create.client.AllPartialModels;
import com.zurrtum.create.client.catnip.render.CachedBuffers;
import com.zurrtum.create.client.catnip.render.SuperByteBuffer;
import com.zurrtum.create.client.foundation.blockEntity.renderer.SmartBlockEntityRenderer;
import com.zurrtum.create.client.foundation.blockEntity.renderer.SmartBlockEntityRenderer.NameplateRenderState;
import com.zurrtum.create.content.logistics.packagePort.postbox.PostboxBlock;
import com.zurrtum.create.content.logistics.packagePort.postbox.PostboxBlockEntity;
import net.minecraft.class_11659;
import net.minecraft.class_11683;
import net.minecraft.class_11954;
import net.minecraft.class_12075;
import net.minecraft.class_12249;
import net.minecraft.class_1921;
import net.minecraft.class_243;
import net.minecraft.class_2561;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4608;
import net.minecraft.class_5614;
import net.minecraft.class_827;
import org.jetbrains.annotations.Nullable;

public class PostboxRenderer implements class_827<PostboxBlockEntity, PostboxRenderer.PostboxRenderState> {
    public PostboxRenderer(class_5614.class_5615 context) {
    }

    @Override
    public PostboxRenderState method_74335() {
        return new PostboxRenderState();
    }

    @Override
    public void extractRenderState(
        PostboxBlockEntity be,
        PostboxRenderState state,
        float tickProgress,
        class_243 cameraPos,
        @Nullable class_11683.class_11792 crumblingOverlay
    ) {
        class_11954.method_74399(be, state, crumblingOverlay);
        state.layer = class_12249.method_75972();
        state.flag = CachedBuffers.partial(AllPartialModels.POSTBOX_FLAG, state.field_62674);
        state.angle = class_3532.field_29847 * (180 - state.field_62674.method_11654(PostboxBlock.field_11177).method_10144());
        LerpedFloat flag = be.flag;
        float value = flag.getValue(tickProgress);
        float progress = (float) (Math.pow(Math.min(value * 5, 1), 2));
        if (flag.getChaseTarget() > 0 && !flag.settled() && progress == 1) {
            float wiggleProgress = (value - .2f) / .8f;
            progress += (float) ((Math.sin(wiggleProgress * (2 * class_3532.field_29844) * 4) / 8f) / Math.max(1, 8f * wiggleProgress));
        }
        state.xRot = class_3532.field_29847 * (-progress * 90);
        String filter = be.addressFilter;
        if (filter != null && !filter.isBlank()) {
            state.name = SmartBlockEntityRenderer.getNameplateRenderState(
                be,
                state.field_62673,
                cameraPos,
                class_2561.method_43470(filter),
                1,
                state.field_62676
            );
        }
    }

    @Override
    public void submit(PostboxRenderState state, class_4587 matrices, class_11659 queue, class_12075 cameraState) {
        queue.method_73483(matrices, state.layer, state);
        if (state.name != null) {
            state.name.render(matrices, queue, cameraState);
        }
    }

    public static class PostboxRenderState extends class_11954 implements class_11659.class_11660 {
        public class_1921 layer;
        public SuperByteBuffer flag;
        public float angle;
        public float xRot;
        public NameplateRenderState name;

        @Override
        public void render(class_4587.class_4665 matricesEntry, class_4588 vertexConsumer) {
            flag.light(field_62676).overlay(class_4608.field_21444).rotateYCentered(angle).translate(0, 0.625f, 0.125f).rotateX(xRot)
                .translate(0, -0.625f, -0.125f).renderInto(matricesEntry, vertexConsumer);
        }
    }
}
